@@ -3,12 +3,6 @@ from contextlib import contextmanager
 
 from tornado.options import options
 
-sqlalchemy_orm = None
-try:
-    sqlalchemy_orm = importlib.import_module("sqlalchemy.orm")
-except ImportError as e:
-    raise Exception(f"sqlalchemy is not exist,run:pip install sqlalchemy==1.4.36")
-
 
 class SqlAlchemyHelper:
     def __init__(self, pool):
@@ -23,6 +17,10 @@ class SqlAlchemyHelper:
 
     @contextmanager
     def make_session(self, **kwargs):
+        try:
+            sqlalchemy_orm = importlib.import_module("sqlalchemy.orm")
+        except ImportError:
+            raise Exception(f"sqlalchemy is not exist,run:pip install sqlalchemy==1.4.36")
         db_session = sqlalchemy_orm.scoped_session(sqlalchemy_orm.sessionmaker(bind=self.pool, **kwargs))
         session = db_session()
         yield session
@@ -58,9 +56,9 @@ def alchemy_default_to_dict(params, data, repetition=False):
             return {}
 
 
-def sqlalchemy_paging(Query, limit_number, offset_number):
-    data_list = Query.limit(limit_number).offset(offset_number).all()
-    data_count = Query.count()
+def sqlalchemy_paging(query, limit_number, offset_number):
+    data_list = query.limit(limit_number).offset(offset_number).all()
+    data_count = query.count()
     return {"count": data_count, "dataSource": data_list}
 
 
