@@ -14,12 +14,12 @@ def sentry_monitor():
             sentry_sdk_tornado = importlib.import_module("sentry_sdk.integrations.tornado")
         except ImportError:
             raise Exception(f"sentry-sdk is not exist,run:pip install sentry-sdk==1.22.2")
-        sentry_config.pop("integrations", "")
+        integrations = sentry_config.pop("integrations", [])
         try:
             sentry_sdk.init(
                 integrations=[
                     sentry_sdk_tornado.TornadoIntegration(),
-                ],
+                ] if not integrations else integrations,
                 **sentry_config
             )
         except Exception:
