@@ -5,7 +5,6 @@ from datetime import datetime
 from decimal import Decimal
 from typing import Optional, Awaitable, Union
 
-from bson import ObjectId
 from tornado.web import RequestHandler
 
 from lesscode.utils.es_log.record_log import es_record_log
@@ -90,14 +89,15 @@ class NativeHandler(RequestHandler):
 
 class JSONEncoder(json.JSONEncoder):
     def default(self, o):
-        if isinstance(o, ObjectId):
+        object_class_name = o.__class__.__name__
+        if object_class_name == "ObjectId":
             return str(o)
-        elif isinstance(o, datetime):
+        elif object_class_name == "datetime":
             return str(o)
-        elif isinstance(o, bytes):
+        elif object_class_name == "bytes":
             return str(o, encoding="utf-8")
-        elif isinstance(o, set):
+        elif object_class_name == "set":
             return list(o)
-        elif isinstance(o, Decimal):
+        elif object_class_name == "Decimal":
             return str(o)
         return json.JSONEncoder.default(self, o)
